tx_people
=========
This Django application was generated using the `Texas Tribune's`__ Generic
Django app template.

.. __: http://www.texastribune.org/


Installation & Configuration
----------------------------
You can install this using `pip`_ like this:

::

    pip install tx_people

Once installed, you need to add it to your ``INSTALLED_APPS``.  You can do that
however you like or you can copy-and-paste this in after your
``INSTALLED_APPS`` are defined.

::

    INSTALLED_APPS += ['tx_people', ]

Now you're ready to start using ``tx_people``.


Usage
-----
*TODO*


Example
-------
All of the usage is outlined, along with tests inside the ``example``
directory.  See that directory for more information on how to run the tests and
example project.

.. _pip: http://www.pip-installer.org/en/latest/

